{
////////////////////////////////////////////////////////////////////////////
////
// OPEN SCRIPTING ARCHITECTURE: Client Interface
////////////////////////////////////////////////////////////////////////////
////
// Copyright   1992 Apple Computer, Inc. All rights reserved.
// Authors: Jens Alfke, William Cook, Donn Denman, and Warren Harris
////////////////////////////////////////////////////////////////////////////
////
// This interface defines what it means to be a "scripting component."
// Scripting components allow "scripts" to be loaded and executed.  This
// interface does not define the way in which a particular scripting
// component's scripts are editing and debugged.
////////////////////////////////////////////////////////////////////////////
////
}

{$IFC UNDEFINED UsingIncludes}
{$SETC UsingIncludes := 0}
{$ENDC}

{$IFC NOT UsingIncludes}
    UNIT AppleScript;
    INTERFACE
{$ENDC}

{$IFC UNDEFINED UsingAppleScript}
{$SETC UsingAppleScript := 1}

{$I+}
{$SETC AppleScriptIncludes := UsingIncludes}
{$SETC UsingIncludes := 1}
{$IFC UNDEFINED UsingAppleEvents}
{$I $$Shell(PInterfaces)AppleEvents.p}
{$ENDC}
{$IFC UNDEFINED UsingComponents}
{$I $$Shell(PInterfaces)Components.p}
{$ENDC}
{$SETC UsingIncludes := AppleScriptIncludes}

{ Types and Constants }
CONST
	typeAppleScript						= 'ascr';
	kAppleScriptSubtype					= typeAppleScript;
	typeASSourceType					= typeChar;
	typeASStorage						= typeAppleScript;
	kASEventClass						= typeAppleScript;

{ Component Selectors }
	kASSelectInit						= $1001;
	kASSelectSetSourceStyles			= $1002;
	kASSelectGetSourceStyles			= $1003;
	kASSelectStringComp					= $1004;
	{ Inspecting }
	kOSASelectSetVariable				= $1101;
	kOSASelectGetVariable				= $1102;
	kOSASelectSetHandler				= $1103;
	kOSASelectGetHandler				= $1104;

{ Dialect Codes }
	kASEnglish							= 129;
	kASJapaneseKanji					= 140;
	kASJapaneseRomaji					= 141;

{ Initialization }

FUNCTION
ASInit(scriptingSystem		: ComponentInstance;
	   initialStackSize		: LONGINT;
	   maxStackSize			: LONGINT;
	   initialHeapSize		: LONGINT;
	   maxHeapSize			: LONGINT)
	: OSAError;

{ Source Styles }

FUNCTION
ASSetSourceStyles(scriptingSystem		: ComponentInstance;
				  sourceStyles			: STHandle)
	: OSAError;

FUNCTION
ASGetSourceStyles(scriptingSystem			: ComponentInstance;
				  VAR resultingSourceStyles	: STHandle)
	: OSAError;

CONST
	kASSourceStyleNormalText				= 0;
	kASSourceStyleLanguageKeyword			= 1;
	kASSourceStyleApplicationKeyword		= 2;
	kASSourceStyleParameter					= 3;
	kASSourceStyleUserSymbol				= 4;
	kASSourceStyleLiteral					= 5;
	kASSourceStyleComment					= 6;
	kASSourceStyleAlias						= 7;
	kASSourceStyleUncompiledText			= 8;
	kASDefaultSourceStyleSize				= 9;

{ Comparison Overloading Hook }

FUNCTION
ASHandleCompEvent(scriptingSystem		: ComponentInstance;
				  event					: AppleEvent;
				  reply					: AppleEvent;
				  refcon				: LONGINT;
				  op					: OSType)
	: OSAError;

{ Manipulating Contexts }

FUNCTION
OSASetVariable(scriptingComponent	: ComponentInstance;
			   contextID			: OSAID;
			   variableName			: AEDesc;
			   scriptValueID		: OSAID)
	: OSAError;

FUNCTION
OSAGetVariable(scriptingComponent			: ComponentInstance;
			   contextID					: OSAID;
			   variableName					: AEDesc;
			   VAR resultingScriptValueID	: OSAID)
	: OSAError;

FUNCTION
OSASetHandler(scriptingComponent	: ComponentInstance;
			  contextID				: OSAID;
			  handlerName			: AEDesc;
			  compiledScriptID		: OSAID)
	: OSAError;

FUNCTION
OSAGetHandler(scriptingComponent			: ComponentInstance;
			  contextID						: OSAID;
			  handlerName					: AEDesc;
			  VAR resultingCompiledScriptID	: OSAID)
	: OSAError;

CONST
	kOSAScriptIsTypeScriptHandler	= 'hdlr';

{$ENDC}    { UsingAppleScript }

{$IFC NOT UsingIncludes}
    END.
{$ENDC}
